@@ -254,6 +254,8 @@ class CoreTests(unittest.TestCase):
         self.assertFalse(p1!=p2)
         self.assertTrue(p1!=p3)
         self.assertTrue(p2!=p3)
+        self.assertTrue(hash(p1)==hash(p2))
+        self.assertTrue(hash(p1)!=hash(p3))
         p2.port=4444
         p2.object="99999"
         self.assertNotEqual(p1,p2)
@@ -262,6 +264,10 @@ class CoreTests(unittest.TestCase):
         self.assertTrue(p2==p3)
         self.assertTrue(p1!=p2)
         self.assertFalse(p2!=p3)
+        self.assertTrue(hash(p1)!=hash(p2))
+        self.assertTrue(hash(p2)==hash(p3))
+        self.assertFalse(p1==42)
+        self.assertTrue(p1!=42)
 
     def testLocation(self):
         self.assertTrue(Pyro4.core.URI.isUnixsockLocation("./u:name"))
@@ -436,6 +442,22 @@ class CoreTests(unittest.TestCase):
         self.assertEqual(True, getattr(t.method,"_pyroCallback"))
         self.assertEqual(False, getattr(t.method2,"_pyroCallback", False))
 
+    def testProxyEquality(self):
+        p1=Pyro4.core.Proxy("PYRO:thing@localhost:15555")
+        p2=Pyro4.core.Proxy("PYRO:thing@localhost:15555")
+        p3=Pyro4.core.Proxy("PYRO:other@machine:16666")
+        self.assertTrue(p1==p2)
+        self.assertFalse(p1!=p2)
+        self.assertFalse(p1==p3)
+        self.assertTrue(p1!=p3)
+        self.assertTrue(hash(p1)==hash(p2))
+        self.assertFalse(hash(p1)==hash(p3))
+        p1._pyroOneway.add("onewaymethod")
+        self.assertFalse(p1==p2)
+        self.assertFalse(hash(p1)==hash(p2))
+        self.assertFalse(p1==42)
+        self.assertTrue(p1!=42)
+
 
 class RemoteMethodTests(unittest.TestCase):
     class BatchProxyMock(object):
