@@ -97,6 +97,21 @@ class DaemonTests(unittest.TestCase):
         self.assertRaises(PyroError, Pyro4.core.Daemon)
         Pyro4.config.SERVERTYPE=old_servertype
 
+    def testRegisterTwice(self):
+        with Pyro4.core.Daemon(port=0) as d:
+            o1=MyObj("object1")
+            d.register(o1)
+            self.assertRaises(DaemonError, d.register, o1, None)
+            d.unregister(o1)
+            d.register(o1)
+            self.assertTrue(hasattr(o1, "_pyroId"))
+            d.unregister(o1)
+            self.assertFalse(hasattr(o1, "_pyroId"))
+            o1._pyroId="FOOBAR"
+            self.assertRaises(DaemonError, d.register, o1, None)
+            o1._pyroId=""
+            d.register(o1)   # with empty-string _pyroId register should worlk
+
     def testRegisterEtc(self):
         freeport=Pyro4.socketutil.findProbablyUnusedPort()
         d=Pyro4.core.Daemon(port=freeport)
@@ -106,11 +121,8 @@ class DaemonTests(unittest.TestCase):
             o2=MyObj("object2")
             d.register(o1)
             self.assertRaises(DaemonError, d.register, o2, Pyro4.constants.DAEMON_NAME)  # cannot use daemon name
-            self.assertRaises(DaemonError, d.register, o1, None)  # cannot register twice
-            self.assertRaises(DaemonError, d.register, o1, "obj1a")
             d.register(o2, "obj2a")
-            self.assertRaises(DaemonError, d.register, o2, "obj2b")
-            
+
             self.assertEqual(3, len(d.objectsById))
             self.assertEqual(o1, d.objectsById[o1._pyroId])
             self.assertEqual(o2, d.objectsById["obj2a"])
@@ -300,6 +312,30 @@ class DaemonTests(unittest.TestCase):
         except ValueError:
             pass
 
+    def testNATzeroPort(self):
+        servertype = Pyro4.config.SERVERTYPE
+        try:
+            Pyro4.config.SERVERTYPE="multiplex"
+            with Pyro4.core.Daemon(nathost="nathosttest", natport=99999) as d:
+                host, port = d.locationStr.split(":")
+                self.assertNotEqual(99999, port)
+                self.assertEqual("nathosttest:99999", d.natLocationStr)
+            with Pyro4.core.Daemon(nathost="nathosttest", natport=0) as d:
+                host, port = d.locationStr.split(":")
+                self.assertEqual("nathosttest:%s" % port, d.natLocationStr)
+            Pyro4.config.SERVERTYPE="thread"
+            with Pyro4.core.Daemon(nathost="nathosttest", natport=99999) as d:
+                host, port = d.locationStr.split(":")
+                self.assertNotEqual(99999, port)
+                self.assertEqual("nathosttest:99999", d.natLocationStr)
+            with Pyro4.core.Daemon(nathost="nathosttest", natport=0) as d:
+                host, port = d.locationStr.split(":")
+                self.assertEqual("nathosttest:%s" % port, d.natLocationStr)
+        finally:
+            Pyro4.config.SERVERTYPE=servertype
+
+
+
     def testNATconfig(self):
         try:
             Pyro4.config.NATHOST=None
